# Gavia
[![License](http://img.shields.io/:license-mit-blue.svg)](http://octopress.mit-license.org) ![Version](https://img.shields.io/badge/version-0.0.2-orange.svg) ![Dependencies](https://img.shields.io/badge/dependencies-up%20to%20date-green.svg) 

Python package for processing science data from the Gavia Autonomous Underwater Vehicle

## Installation
Full instructions can be found <a href="https://github.com/brett-hosking/gavia/blob/master/docs/Install.md" target="_blank">here </a>

### Install Package using **pip**
    pip install gavia 

## Usage
Click <a href="https://github.com/brett-hosking/gavia/blob/master/docs/Examples.md" target="_blank">here </a> for usage examples

